@@ -1,5 +1,5 @@
 'use strict';
-var path = require('path');
+let path = require('path');
 var webpack = require('webpack');
 var HtmlWebpackPlugin = require('html-webpack-plugin');
 //let defaultSettings = require('./defaults');
@@ -24,7 +24,8 @@ module.exports = {
            template:'./index.html',    //html模板路径
            inject:true,    //允许插件修改哪些内容，包括head与body
            hash:true,      //为静态资源生成hash值
-    })
+    }),
+      ["import", [{ "libraryName": "antd", "style": "css" }]]
   ],
   resolve: {
       extensions: ['', '.js', '.jsx','.json', '.scss'],
@@ -78,11 +79,10 @@ module.exports = {
       {
          test: /\.jsx?$/,
           loader: 'babel-loader',
-          //loader: 'react-hot-loader/webpack!babel-loader',
-          // loader:['babel'],
-          query: {
-                presets: ['es2015', 'react', 'stage-1']//先后顺序不能错,否则有些语法转换会报错
-          },
+
+          //query: {
+          //      presets: ['es2015', 'react', 'stage-1']//先后顺序不能错,否则有些语法转换会报错
+          //},
          exclude: /node_modules/,
           include:[path.join(__dirname,"/../resources/")]
       }
